@@ -8,7 +8,7 @@ from functools import reduce
 from typing import Any, List, Dict, Optional, Union, Callable
 
 import jsbeautifier
-from strbuilder import BaseBuilder, SurroundBuilder
+from strbuilder import Builder, SurroundBuilder
 
 from .visitor import Visitor, VisitorContext
 
@@ -125,7 +125,7 @@ class CodeGen(Visitor[JSVisitorContext]):
         return [f'import * as {x.asname} from "{x.name}"' if x.asname else f'import "{x.name}"' for x in node.names]
 
     def visit_ImportFrom(self, node: ast.ImportFrom, ctx: JSVisitorContext):
-        builder = BaseBuilder(separator=',')
+        builder = Builder(separator=',')
         for item in node.names:
             if item.name == '*':
                 builder.write(f'/* Wildcard import not supported: {node.module} */')
@@ -139,7 +139,7 @@ class CodeGen(Visitor[JSVisitorContext]):
 
         body = node.body
         name = ast.Name(node.name)
-        builder = BaseBuilder()\
+        builder = Builder()\
             .write(f'let {node.name} = class')\
             .write(SurroundBuilder(surround='{}')
                    .write_if(self.python_compatible, lambda: '''constructor(...args) {if ('__init__' in this) this.__init__(...args); return new Proxy(this, { apply: (target, self, args) => target.__call__(...args), get: (target, key) => target.__getitem__(key) })}''')
@@ -157,7 +157,7 @@ class CodeGen(Visitor[JSVisitorContext]):
 
         body = self.visit(node.body, context)
         if ctx.scope == JSScope.CLASS_FIELD:
-            builder = BaseBuilder()
+            builder = Builder()
             builder.write_if(context.has_yield, '*')
             builder.write(node.name)
             if self.python_compatible:
@@ -177,7 +177,7 @@ class CodeGen(Visitor[JSVisitorContext]):
                            .write(body))
                 )
             return builder.build()
-        builder = BaseBuilder()\
+        builder = Builder()\
             .write_if(not ctx.is_existed(node.name), 'let')\
             .write(node.name)\
             .write('=')\
@@ -195,14 +195,14 @@ class CodeGen(Visitor[JSVisitorContext]):
         body = self.visit(node.body, context)
 
         if ctx.scope == JSScope.CLASS_FIELD:
-            return BaseBuilder()\
+            return Builder()\
                 .write_if(context.has_yield, '*')\
                 .write(node.name)\
                 .write(f'{self.visit(node.args, ctx)}')\
                 .write(SurroundBuilder(surround='{}')
                        .write(body))\
                 .build()
-        builder = BaseBuilder()\
+        builder = Builder()\
             .write_if(not ctx.is_existed(node.name), 'let')\
             .write(node.name)\
             .write('=')\
@@ -223,10 +223,10 @@ class CodeGen(Visitor[JSVisitorContext]):
         return f'yield* {self.visit(node.value, ctx)}'
 
     def visit_If(self, node: ast.If, ctx: JSVisitorContext):
-        return BaseBuilder('if').write(SurroundBuilder(surround='()').write(self.visit(node.test, ctx))).write(SurroundBuilder(surround='{}').write(self.visit(node.body, ctx))).build()
+        return Builder('if').write(SurroundBuilder(surround='()').write(self.visit(node.test, ctx))).write(SurroundBuilder(surround='{}').write(self.visit(node.body, ctx))).build()
 
     def visit_Compare(self, node: ast.Compare, ctx: JSVisitorContext):
-        ops = BaseBuilder()
+        ops = Builder()
         invert = False
         for op in node.ops:
             op_type = type(op)
@@ -234,7 +234,7 @@ class CodeGen(Visitor[JSVisitorContext]):
             if op_type == ast.NotIn:
                 invert = True
 
-        builder = BaseBuilder(self.visit(node.left, ctx))
+        builder = Builder(self.visit(node.left, ctx))
         comparators = node.comparators
         while comparators:
             builder.write(ops.pop(0))
@@ -250,7 +250,7 @@ class CodeGen(Visitor[JSVisitorContext]):
         return self.CONSTANT_CONSUMER_TABLE[type(node.value)](node.value, ctx)
 
     def visit_Assign(self, node: ast.Assign, ctx: JSVisitorContext):
-        builder = BaseBuilder(separator=';')
+        builder = Builder(separator=';')
 
         defines = [target.id for target in node.targets if isinstance(target, ast.Name) and not ctx.is_existed(target.id)]
         ctx.variables.extend(defines)
@@ -263,7 +263,7 @@ class CodeGen(Visitor[JSVisitorContext]):
                 builder.write(f'let {", ".join(defines)}')
         builder.write(f'{self.visit(node.targets, ctx)} = {self.visit(node.value, ctx)}')
         return builder.build()
-        # return BaseBuilder().write_if(node.targets in ctx.variables and ctx.scope != JSScope.CLASS_FIELD and not any(map(lambda target: isinstance(target, ast.Attribute), node.targets)), 'let').write(f'{self.visit(node.targets, ctx)} = {self.visit(node.value, ctx)}').build()
+        # return Builder().write_if(node.targets in ctx.variables and ctx.scope != JSScope.CLASS_FIELD and not any(map(lambda target: isinstance(target, ast.Attribute), node.targets)), 'let').write(f'{self.visit(node.targets, ctx)} = {self.visit(node.value, ctx)}').build()
 
     def visit_Call(self, node: ast.Call, ctx: JSVisitorContext):
         context = ctx.copy(scope=JSScope.ARGUMENT)
@@ -271,7 +271,7 @@ class CodeGen(Visitor[JSVisitorContext]):
         starreds = tuple(filter(lambda arg: isinstance(arg, ast.Starred), node.args))
         args = filter(lambda arg: not isinstance(arg, ast.Starred), node.args)
 
-        return BaseBuilder(f'{self.visit(node.func, ctx)}')\
+        return Builder(f'{self.visit(node.func, ctx)}')\
             .write(SurroundBuilder(surround='()', separator=',')
                    .write_if(args, lambda: self.visit(args, context))
                    .write_if(node.keywords, lambda: SurroundBuilder(surround='{}', separator=',')
@@ -293,7 +293,7 @@ class CodeGen(Visitor[JSVisitorContext]):
 
         return SurroundBuilder(surround='()')\
             .write(
-            BaseBuilder(separator=',')
+            Builder(separator=',')
             .write_if(node.args, self.visit(args, context))
             .write_if(node.kwarg or node.defaults, lambda:
                       SurroundBuilder(surround='{}', separator=',')
@@ -332,14 +332,14 @@ class CodeGen(Visitor[JSVisitorContext]):
         return f'{self.visit(node.args, ctx)}=> {{return {self.visit(node.body, ctx)}}}'
 
     def visit_For(self, node: ast.For, ctx: JSVisitorContext):
-        target = BaseBuilder()
+        target = Builder()
         if isinstance(node.target, ast.Name):
             if not ctx.is_existed(node.target.id):
                 target.write(f'let')
         target.write(self.visit(node.target, ctx))
 
         return (
-            BaseBuilder()
+            Builder()
             .write_if(node.orelse, '__else: {')
             .write(f'for ({target.build()} of {self.visit(node.iter, ctx)})')
             .write(f"{{{self.visit(node.body, ctx.copy(break_suffix='__else' if node.orelse else ''))}}}")
@@ -348,7 +348,7 @@ class CodeGen(Visitor[JSVisitorContext]):
 
     def visit_AsyncFor(self, node: ast.AsyncFor, ctx: JSVisitorContext):
         return (
-            BaseBuilder()
+            Builder()
             .write_if(node.orelse, '__else: {')
             .write(f'for await ({self.visit(node.target, ctx)} of {self.visit(node.iter, ctx)})')
             .write(f"{{{self.visit(node.body, ctx.copy(break_suffix='__else' if node.orelse else ''))}}}")
@@ -373,7 +373,7 @@ class CodeGen(Visitor[JSVisitorContext]):
         return f'Object.fromEntries({self.visit(node.generators, ctx)})'
 
     def visit_comprehension(self, node: ast.comprehension, ctx: JSVisitorContext):
-        builder = BaseBuilder(f'{self.visit(node.iter, ctx)}')
+        builder = Builder(f'{self.visit(node.iter, ctx)}')
         target = self.visit(node.target, ctx)
         builder.write_if(node.ifs, (f'.filter({target}=>{self.visit(x, ctx)})' for x in node.ifs))
 
@@ -401,7 +401,7 @@ class CodeGen(Visitor[JSVisitorContext]):
         if isinstance(node.target, ast.Name):
             ctx.variables.append(node.target.id)
         return (
-            BaseBuilder()
+            Builder()
             .write_if(not isinstance(node.target, ast.Attribute) and ctx.scope != JSScope.CLASS_FIELD, 'let')
             .write(f'{self.visit(node.target, ctx)}')
             .write_if(node.value is not None, lambda: f'={self.visit(node.value, ctx)}')
@@ -413,15 +413,15 @@ class CodeGen(Visitor[JSVisitorContext]):
     def visit_With(self, node: ast.With, ctx: JSVisitorContext):
         builder = SurroundBuilder(surround='{}', separator=';')
         builder.write(
-            BaseBuilder('let')
+            Builder('let')
             .write(SurroundBuilder(surround='[]', separator=',')
                    .write(f'__with_{i}' for i, expr in enumerate(node.items)))
             .write('=')
             .write(SurroundBuilder(surround='[]', separator=',').write(f'{self.visit(expr.context_expr)}' for expr in node.items))
         )\
-            .write(BaseBuilder(separator=';').write(BaseBuilder().write_if(expr.optional_vars, f'{self.visit(expr.optional_vars)}=').write(f'__with_{i}.__enter__()') for i, expr in enumerate(node.items)))\
+            .write(Builder(separator=';').write(Builder().write_if(expr.optional_vars, f'{self.visit(expr.optional_vars)}=').write(f'__with_{i}.__enter__()') for i, expr in enumerate(node.items)))\
             .write(self.visit(node.body))\
-            .write(BaseBuilder(separator=';').write(BaseBuilder().write_if(expr.optional_vars, f'{self.visit(expr.optional_vars)}=').write(f'__with_{i}.__exit__()') for i, expr in enumerate(node.items)))
+            .write(Builder(separator=';').write(Builder().write_if(expr.optional_vars, f'{self.visit(expr.optional_vars)}=').write(f'__with_{i}.__exit__()') for i, expr in enumerate(node.items)))
 
         return builder.build()
 
@@ -471,11 +471,11 @@ class CodeGen(Visitor[JSVisitorContext]):
 
     def visit_Try(self, node: ast.Try, ctx: JSVisitorContext):
         return (
-            BaseBuilder(separator='')
+            Builder(separator='')
             .write_if(node.orelse, '__else: {')
             .write(f'try {{{self.visit(node.body, ctx)}}}')
             .write_if(node.handlers, "catch(__err) {%s}" % '\n'.join(
-                BaseBuilder()
+                Builder()
                 .write_if(handler.type, lambda: f'if (__err instanceof {self.visit(handler.type, ctx)})')
                 .write(SurroundBuilder(surround='{}', separator=';')
                        .write_if(handler.name, f'{handler.name} = __err')
@@ -485,7 +485,7 @@ class CodeGen(Visitor[JSVisitorContext]):
                 .build()
                 for handler in node.handlers
             ))
-            .write_if(node.finalbody, BaseBuilder(f'finally {{{self.visit(node.finalbody, ctx)}').write('}'))
+            .write_if(node.finalbody, Builder(f'finally {{{self.visit(node.finalbody, ctx)}').write('}'))
             .write_if(node.orelse, f'{self.visit(node.orelse, ctx)}}}')
         ).build()
 
